@@ -4,4 +4,8 @@
 from pythium._impl import ios_find_by, ios_find_all
 from pythium._impl import android_find_by, android_find_all
 from pythium._impl import find_by, find_all
-from pythium._impl import by, Page
+from pythium._impl import by, Page, elem_with_driver
+from pythium._impl import WebElement, MobileElement
+from pythium.objects import Element, Elements
+from pythium.browsers import Browsers
+
